# from holboxai.file1 import firstclass
# from holboxai.file2 import secondclass
# from holboxai.file3 import sort
from holboxai.s3_reader import S3DocReader
from holboxai.docs_query import DocsQuery
from holboxai.relevant_docs import RelevantDocs
from holboxai.csv_query import CsvQuery
from holboxai.text2image import text2image
from holboxai.sentiment_analysis import SentimentAnalysis
from holboxai.name_entity_recognition import NameEntityRecognition
from holboxai.summarizer import Summarizer
